{ config, pkgs, ... }: {
  imports = [
    ../../templates/proxmox-lxc.nix
    ../../server.nix
    ../../features/podman.nix
  ];

  networking.hostName = "woodpecker";
  system.stateVersion = "25.05";
  nixpkgs.hostPlatform = "x86_64-linux";

  sops.secrets.woodpecker_agent_secret = {
    sopsFile = ../../../secrets/woodpecker/default.yaml;
  };
  sops.secrets.woodpecker_forgejo_client = {
    sopsFile = ../../../secrets/woodpecker/default.yaml;
  };
  sops.secrets.woodpecker_forgejo_secret = {
    sopsFile = ../../../secrets/woodpecker/default.yaml;
  };

  sops.templates.woodpecker-env = {
    content = ''
WOODPECKER_FORGEJO_CLIENT=${config.sops.placeholder.woodpecker_forgejo_client}
WOODPECKER_FORGEJO_SECRET=${config.sops.placeholder.woodpecker_forgejo_secret}
    '';
  };

    sops.templates.woodpecker-agent-env = {
    content = ''
WOODPECKER_AGENT_SECRET=${config.sops.placeholder.woodpecker_agent_secret}
    '';
  };


  services.woodpecker-server = {
    enable = true;
    environment = {
      WOODPECKER_HOST = "https://ci.sapphic.engineer";
      WOODPECKER_SERVER_ADDR = ":9001";
      WOODPECKER_OPEN = "true";
      WOODPECKER_FORGEJO = "true";
      WOODPECKER_FORGEJO_URL = "https://git.sapphic.engineer";
      WOODPECKER_ADMIN = "noe";
    };
    environmentFile = config.sops.templates.woodpecker-env.path;
  };

  environment.systemPackages = [
    pkgs.woodpecker-cli
  ];

  services.woodpecker-agents.agents."docker" = {
    enable = true;
    environment = {
      WOODPECKER_SERVER = "localhost:9000";
      WOODPECKER_BACKEND = "docker";
      WOODPECKER_MAX_WORKFLOWS = "4";
      DOCKER_HOST = "unix:///run/podman/podman.sock";
      WOODPECKER_HEALTHCHECK = "false";
      WOODPECKER_GRPC_SECURE = "false";
    };
    environmentFile = [ config.sops.templates.woodpecker-agent-env.path ];
    extraGroups = [ "podman" ];
  };

  virtualisation.podman = {
    defaultNetwork.settings = {
      dns_enabled = true;
    };
    autoPrune = {
      enable = true;
      dates = "daily";
    };
  };

  virtualisation.containers = {
    containersConf.settings = {
      network.default_subnet_pools = [{ base = "192.168.100.0/23"; size = 23; }];
    };
  };
}
